@@ -1202,6 +1202,20 @@ def test_CiscoRange_24():
     )
 
 
+def test_CiscoRange_25():
+    """If we ask for an int, ensure we get an int"""
+    uut = CiscoRange("15-20", result_type=int)
+    for value in uut:
+        assert isinstance(value, int)
+
+
+def test_CiscoRange_26():
+    """If we ask for a list of ints, ensure we get an int"""
+    uut = CiscoRange("15-20", result_type=int).as_list(result_type=int)
+    for value in uut:
+        assert isinstance(value, int)
+
+
 def test_CiscoRange_compressed_str_01():
     """compressed_str test with a very basic set of vlan numbers"""
     uut_str = "1,2,911"
