@@ -1,63 +1,58 @@
-""" test_Models_Asa.py - Parse, Query, Build, and Modify IOS-style configs
+"""test_Models_Asa.py - Parse, Query, Build, and Modify IOS-style configs
 
-     Copyright (C) 2020-2021 David Michael Pennington at Cisco Systems
-     Copyright (C) 2019      David Michael Pennington at ThousandEyes
-     Copyright (C) 2014-2019 David Michael Pennington at Samsung Data Services
+Copyright (C) 2023-2025      David Michael Pennington at Cisco Systems
 
-     This program is free software: you can redistribute it and/or modify
-     it under the terms of the GNU General Public License as published by
-     the Free Software Foundation, either version 3 of the License, or
-     (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
-     This program is distributed in the hope that it will be useful,
-     but WITHOUT ANY WARRANTY; without even the implied warranty of
-     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-     GNU General Public License for more details.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-     You should have received a copy of the GNU General Public License
-     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-     If you need to contact the author, you can do so by emailing:
-     mike [~at~] pennington [.dot.] net
+If you need to contact the author, you can do so by emailing:
+mike [~at~] pennington [.dot.] net
 """
 
-from collections.abc import MutableSequence
-import uuid
-import sys
-import re
 import os
+import re
+import sys
+import uuid
+from collections.abc import MutableSequence
 
 sys.path.insert(0, "..")
 
 import pytest
+from ciscoconfparse2.ccp_util import IPv4Obj, L4Object
+from ciscoconfparse2.ciscoconfparse2 import CiscoConfParse
+from ciscoconfparse2.models_asa import ASAObjGroupService
+
 from conftest import parse_a01, parse_a01_factory
 
-from ciscoconfparse.ciscoconfparse import CiscoConfParse
-from ciscoconfparse.models_asa import ASAObjGroupService
-from ciscoconfparse.ccp_util import L4Object
-from ciscoconfparse.ccp_util import IPv4Obj
-
 if sys.version_info[0] < 3:
-    from ipaddr import IPv4Network, IPv6Network, IPv4Address, IPv6Address
+    from ipaddr import IPv4Address, IPv4Network, IPv6Address, IPv6Network
 else:
     from ipaddress import IPv4Network, IPv6Network, IPv4Address, IPv6Address
 
 from loguru import logger
 
 
-
-
 def testVal_Access_List(parse_a01_factory):
     result_correct = {}
-    assert len(parse_a01_factory.objs.access_list["INSIDE_in"]) == 4
+    assert len(parse_a01_factory.objs.asa_access_list["INSIDE_in"]) == 4
 
 
 def testParse_asa_factory(config_a02):
     parse = CiscoConfParse(config_a02, syntax="asa", factory=True)
-    assert (parse is not None)
+    assert parse is not None
 
 
-def testVal_Names(parse_a01, parse_a01_factory):
+def testVal_Asa_Object_Group_Names(parse_a01, parse_a01_factory):
     result_correct = {
         "dmzsrv00": "1.1.3.10",
         "dmzsrv01": "1.1.3.11",
@@ -65,8 +60,8 @@ def testVal_Names(parse_a01, parse_a01_factory):
         "dmzsrv03": "1.1.3.13",
         "loghost01": "1.1.2.20",
     }
-    assert parse_a01.ConfigObjs.names == result_correct
-    assert parse_a01_factory.ConfigObjs.names == result_correct
+    assert parse_a01.config_objs.asa_object_group_names == result_correct
+    assert parse_a01_factory.config_objs.asa_object_group_names == result_correct
 
 
 def testVal_object_group_network_01():
@@ -82,7 +77,7 @@ def testVal_object_group_network_01():
         " network-object 1.1.2.0 255.255.255.0",
         "!",
     ]
-    cfg_factory = CiscoConfParse(conf, factory=True, syntax="asa")
+    cfg_factory = CiscoConfParse(conf, syntax="asa", factory=True)
     obj = cfg_factory.find_objects(r"object-group\snetwork")[0]
 
     result_correct_01 = [
@@ -142,16 +137,24 @@ def testVal_object_group_network_02():
     assert obj.networks == result_correct_01
 
 
-def testVal_ipv4_addr():
+def testVal_ipv4_addr_01():
     conf = [
+        "hostname MYASA",
         "!",
         "interface Ethernet0/0",
         " nameif OUTSIDE",
         " ip address 198.101.172.106 255.255.255.128 standby 198.101.172.107",
+        " ipv6 address 2001:dead:beef::1/64 standby 2001:dead:beef::2",
+        " ipv6 enable",
         "!",
         "interface Ethernet0/1",
         " nameif INSIDE",
         " ip address 192.0.2.254 255.255.255.0",
+        " ipv6 address fd80::1/64 standby fd80::2",
+        " ipv6 enable",
+        "!",
+        "interface Ethernet0/2",
+        " shutdown",
         "!",
     ]
     cfg_factory = CiscoConfParse(conf, factory=True, syntax="asa")
@@ -165,6 +168,70 @@ def testVal_ipv4_addr():
     assert obj.ipv4_addr == "192.0.2.254"
 
 
+def testVal_ipv6_addr_01():
+    conf = [
+        "hostname MYASA",
+        "!",
+        "interface Ethernet0/0",
+        " nameif OUTSIDE",
+        " ip address 198.101.172.106 255.255.255.128 standby 198.101.172.107",
+        " ipv6 address 2001:dead:beef::1/64 standby 2001:dead:beef::2",
+        " ipv6 enable",
+        "!",
+        "interface Ethernet0/1",
+        " nameif INSIDE",
+        " ip address 192.0.2.254 255.255.255.0",
+        " ipv6 address fd80::1/64 standby fd80::2",
+        " ipv6 enable",
+        "!",
+        "interface Ethernet0/2",
+        " shutdown",
+        "!",
+    ]
+    cfg_factory = CiscoConfParse(conf, factory=True, syntax="asa")
+
+    obj = cfg_factory.find_objects(r"^interface\sEthernet0\/0$")[0]
+    assert obj.ipv6_addr == "2001:dead:beef::1"
+    assert obj.ipv6_standby_addr == "2001:dead:beef::2"
+    assert obj.ipv6_masklength == 64
+
+    obj = cfg_factory.find_objects(r"^interface\sEthernet0\/1$")[0]
+    assert obj.ipv6_addr == "fd80::1"
+    assert obj.ipv6_standby_addr == "fd80::2"
+    assert obj.ipv6_masklength == 64
+
+    obj = cfg_factory.find_objects(r"^interface\sEthernet0\/2$")[0]
+    assert obj.ipv6_addr == ""
+    assert obj.ipv6_standby_addr == ""
+    assert obj.ipv6_masklength == 0
+
+
+def testVal_interface_name_01():
+    conf = [
+        "hostname MYASA",
+        "!",
+        "interface Ethernet0/0",
+        " nameif OUTSIDE",
+        " ip address 198.101.172.106 255.255.255.128 standby 198.101.172.107",
+        " ipv6 address 2001:dead:beef::1/64 standby 2001:dead:beef::2",
+        " ipv6 enable",
+        "!",
+        "interface Ethernet0/1",
+        " nameif INSIDE",
+        " ip address 192.0.2.254 255.255.255.0",
+        " ipv6 address fd80::1/64 standby fd80::2",
+        " ipv6 enable",
+        "!",
+        "interface Ethernet0/2",
+        " shutdown",
+        "!",
+    ]
+    cfg_factory = CiscoConfParse(conf, factory=True, syntax="asa")
+
+    obj = cfg_factory.find_objects(r"^interface\sEthernet0\/0$")[0]
+    assert obj.name == "Ethernet0/0"
+
+
 def testVal_object_group_service_01():
     ## This can only be configured as protocol object-group
     conf = [
@@ -325,12 +392,21 @@ def testVal_ASAAclLine_DNA_negative():
 
     # Ensure that parsing the bogus ACL line in a config list raises a ValueError
     #     but ValueError triggers a SystemExit
-    broken_config_list = ["access-list TESTME_01 extended VpAAmit987 ip any any log deactivate"]
+    broken_config_list = [
+        "access-list TESTME_01 extended VpAAmit987 ip any any log deactivate"
+    ]
     broken_config_list = ["access-list TESTME_01 extended VpAAmit987 ip any any log"]
     broken_filepath = "/%s" % str(uuid.uuid4())
 
     try:
-        if isinstance(broken_config_list, (MutableSequence, tuple, list,)):
+        if isinstance(
+            broken_config_list,
+            (
+                MutableSequence,
+                tuple,
+                list,
+            ),
+        ):
             parse = CiscoConfParse(broken_config_list, factory=True, syntax="asa")
 
         # Ensure that parsing the bogus filepath string raises OSError
